pitchtools.harmonic_chromatic_interval_class_number_dictionary
==============================================================

.. autofunction:: abjad.tools.pitchtools.harmonic_chromatic_interval_class_number_dictionary.harmonic_chromatic_interval_class_number_dictionary
   :noindex:
